@@ -1,28 +1,36 @@
 from .__string import _string as string
+from ._assets import _assets as assets
 from ._cookies import _cookies as cookies
 from ._datetime import _datetime as datetime
+from ._execute import _execute as execute
 from ._file import _file as file
 from ._headers import _headers as headers
 from ._html import _html as html
 from ._image import _image as image
 from ._list import _list as list  # noqa
+from ._logger import _logger as logger
 from ._math import _math as math
 from ._pandas import _pandas as pandas
+from ._sql import _sql as sql
 from ._types import _types as types
 from ._url import _url as url
 from ._validators import _validators as validators
 
 __all__ = [
     "string",
+    "assets",
     "cookies",
     "datetime",
+    "execute",
     "file",
     "headers",
     "html",
     "image",
     "list",
+    "logger",
     "math",
     "pandas",
+    "sql",
     "types",
     "url",
     "validators",
